@@ -2,9 +2,13 @@ package resourcehandler
 
 import (
 	"fmt"
+	"os"
+	"path/filepath"
 
 	"github.com/armosec/armoapi-go/armotypes"
+	giturl "github.com/armosec/go-git-url"
 	"github.com/armosec/k8s-interface/workloadinterface"
+	"github.com/armosec/opa-utils/reporthandling"
 	"k8s.io/apimachinery/pkg/version"
 
 	"github.com/armosec/k8s-interface/k8sinterface"
@@ -33,35 +37,59 @@ func (fileHandler *FileResourceHandler) GetResources(sessionObj *cautils.OPASess
 	// map resources based on framework required resources: map["/group/version/kind"][]<k8s workloads ids>
 	k8sResources := setK8sResourceMap(sessionObj.Policies)
 	allResources := map[string]workloadinterface.IMetadata{}
-	workloadIDToSource := make(map[string]string, 0)
+	workloadIDToSource := make(map[string]reporthandling.Source, 0)
 	armoResources := &cautils.ArmoResources{}
 
 	workloads := []workloadinterface.IMetadata{}
 
+	if len(fileHandler.inputPatterns) == 0 {
+		return nil, nil, nil, fmt.Errorf("missing input")
+	}
+	path := fileHandler.inputPatterns[0]
+
+	// Clone git repository if needed
+	gitURL, err := giturl.NewGitURL(path)
+	if err == nil {
+		logger.L().Info("cloning", helpers.String("repository url", gitURL.GetURL().String()))
+		cautils.StartSpinner()
+		cloneDir, err := cloneRepo(gitURL)
+		cautils.StopSpinner()
+		if err != nil {
+			return nil, allResources, nil, fmt.Errorf("failed to clone git repo '%s',  %w", gitURL.GetURL().String(), err)
+		}
+		defer os.RemoveAll(cloneDir)
+		path = filepath.Join(cloneDir, gitURL.GetPath())
+	}
+
 	// load resource from local file system
-	sourceToWorkloads, err := cautils.LoadResourcesFromFiles(fileHandler.inputPatterns)
+	logger.L().Info("Accessing local objects")
+
+	sourceToWorkloads, err := cautils.LoadResourcesFromFiles(path)
 	if err != nil {
 		return nil, allResources, nil, err
 	}
+
+	// Get repo root
+	repoRoot := ""
+	giRepo, err := cautils.NewLocalGitRepository(path)
+	if err == nil {
+		repoRoot, _ = giRepo.GetRootDir()
+	}
+
 	for source, ws := range sourceToWorkloads {
 		workloads = append(workloads, ws...)
+
+		relSource, err := filepath.Rel(repoRoot, source)
+		if err == nil {
+			source = relSource
+		}
 		for i := range ws {
-			workloadIDToSource[ws[i].GetID()] = source
+			workloadIDToSource[ws[i].GetID()] = reporthandling.Source{RelativePath: source}
 		}
 	}
 	logger.L().Debug("files found in local storage", helpers.Int("files", len(sourceToWorkloads)), helpers.Int("workloads", len(workloads)))
 
-	// load resources from url
-	sourceToWorkloads, err = loadResourcesFromUrl(fileHandler.inputPatterns)
-	if err != nil {
-		return nil, allResources, nil, err
-	}
-	for source, ws := range sourceToWorkloads {
-		workloads = append(workloads, ws...)
-		for i := range ws {
-			workloadIDToSource[ws[i].GetID()] = source
-		}
-	}
+	// addCommitData(fileHandler.inputPatterns[0], workloadIDToSource)
 
 	if len(workloads) == 0 {
 		return nil, allResources, nil, fmt.Errorf("empty list of workloads - no workloads found")
@@ -70,7 +98,7 @@ func (fileHandler *FileResourceHandler) GetResources(sessionObj *cautils.OPASess
 
 	sessionObj.ResourceSource = workloadIDToSource
 
-	// map all resources: map["/group/version/kind"][]<k8s workloads>
+	// map all resources: map["/apiVersion/version/kind"][]<k8s workloads>
 	mappedResources := mapResources(workloads)
 
 	// save only relevant resources
@@ -89,8 +117,9 @@ func (fileHandler *FileResourceHandler) GetResources(sessionObj *cautils.OPASess
 		logger.L().Warning("failed to collect images vulnerabilities", helpers.Error(err))
 	}
 
-	return k8sResources, allResources, armoResources, nil
+	logger.L().Success("Accessed to local objects")
 
+	return k8sResources, allResources, armoResources, nil
 }
 
 func (fileHandler *FileResourceHandler) GetClusterAPIServerInfo() *version.Info {
@@ -125,3 +154,25 @@ func mapResources(workloads []workloadinterface.IMetadata) map[string][]workload
 	return allResources
 
 }
+
+func addCommitData(input string, workloadIDToSource map[string]reporthandling.Source) {
+	giRepo, err := cautils.NewLocalGitRepository(input)
+	if err != nil {
+		return
+	}
+	for k := range workloadIDToSource {
+		sourceObj := workloadIDToSource[k]
+		lastCommit, err := giRepo.GetFileLastCommit(sourceObj.RelativePath)
+		if err != nil {
+			continue
+		}
+		sourceObj.LastCommit = reporthandling.LastCommit{
+			Hash:           lastCommit.SHA,
+			Date:           lastCommit.Author.Date,
+			CommitterName:  lastCommit.Author.Name,
+			CommitterEmail: lastCommit.Author.Email,
+			Message:        lastCommit.Message,
+		}
+		workloadIDToSource[k] = sourceObj
+	}
+}
